@@ -115,7 +115,7 @@ $SIG{'INT'}  = sub { $F->clip_reset(); $F->cls('ON'); exec('reset'); };
 $F->wait_for_console(!$rpi);
 $F->cls('OFF');
 $F->splash($VERSION);
-
+update();
 sleep 1;
 # $F->acceleration(0);
 # if (0) {
@@ -178,7 +178,7 @@ blit_move();
 rotate();
 flipping();
 monochrome();
-foreach my $m (1 .. 10) {
+foreach my $m (1 .. 9) { # We skip divide mode because it's stupid and I should never have added it
     if ($m == MASK_MODE) {
         mask_drawing();
     } elsif ($m == UNMASK_MODE) {
@@ -1506,6 +1506,7 @@ sub print_it {
     $fb->clip_reset();
     $fb->set_b_color($bgcolor);
     $fb->cls();
+    system('clear');
     unless ($XX <= 320) {
         $fb->or_mode();
 
@@ -1514,11 +1515,12 @@ sub print_it {
                 'x'            => 5 * $xm,
                 'y'            => max(18, 25 * $ym),
                 'height'       => max(9, 20 * $ym),
+                'wscale'       => 1.25,
                 'color'        => $color,
-                'text'         => $message,
+                'text'         => uc($message),
                 'bounding_box' => 1,
                 'center'       => CENTER_X,
-                'antialias'    => 1
+                'antialias'    => 0
             }
         );
         $fb->ttf_print($b);
@@ -1533,10 +1535,10 @@ sub print_it {
 } ## end sub print_it
 
 sub update {
-    my $now = sprintf('%.1f',time);
-    if ($now ne $STAMP) {
+    my $now = time;
+    if ($now > $STAMP) {
         $FR->blit_flip($F) if ($DB);
-        $STAMP = $now;
+        $STAMP = $now + (1 / 30);
     }
 }
 
