@@ -12,7 +12,7 @@ use constant {
 use List::Util qw(min max);
 
 BEGIN {
-    our $VERSION = 1.01;
+    our $VERSION = 1.02;
 }
 
 sub _perl_logo {
@@ -20,13 +20,15 @@ sub _perl_logo {
     return unless (exists($self->{'FONTS'}->{'DejaVuSerif'}));
     my $hf = $self->{'H_SCALE'};
     my $vf = $self->{'V_SCALE'};
+    my $X  = $self->{'H_OFFSET'};
+    my $Y  = $self->{'V_OFFSET'};
 
     $self->normal_mode();
     $self->set_color({ 'red' => 0, 'green' => 0, 'blue' => 0, 'alpha' => 128 });
     $self->ellipse(
         {
-            'x'       => 965 * $hf,
-            'y'       => 70 * $vf,
+            'x'       => (965 * $hf) + $X,
+            'y'       => (70 * $vf) + $Y,
             'xradius' => 140 * $hf,
             'yradius' => 65 * $vf,
             'filled'  => TRUE
@@ -35,8 +37,8 @@ sub _perl_logo {
     $self->set_color({ 'red' => 0, 'green' => 64, 'blue' => 255, 'alpha' => 255 });
     $self->ellipse(
         {
-            'x'       => 960 * $hf,
-            'y'       => 65 * $vf,
+            'x'       => (960 * $hf) + $X,
+            'y'       => (65 * $vf) + $Y,
             'xradius' => 140 * $hf,
             'yradius' => 65 * $vf,
             'filled'  => TRUE
@@ -48,7 +50,7 @@ sub _perl_logo {
         $self->ttf_print(
             {
                 'bounding_box' => TRUE,
-                'y'            => 126 * $vf,                                     # 85 * $vf,
+                'y'            => (126 * $vf) + $Y,                                     # 85 * $vf,
                 'height'       => 80 * $vf,
                 'wscale'       => 1,
                 'color'        => '0040FFFF',
@@ -76,6 +78,8 @@ sub splash {
     my $vf = $H / 1080;
     $self->{'H_SCALE'} = $hf;
     $self->{'V_SCALE'} = $vf;
+    $self->{'H_OFFSET'} = $X;
+    $self->{'V_OFFSET'} = $Y;
 
     my $bold = $self->{'FONT_FACE'};
     $bold =~ s/\.ttf$/Bold.ttf/;
@@ -84,7 +88,7 @@ sub splash {
     $self->clip_reset();
     $self->normal_mode();
 
-    if (1 && (($W <= 320) || ($H <= 240))) {
+    if ((($W <= 320) || ($H <= 240))) {
         $hf = $W / 320;
         $vf = $H / 240;
 
@@ -247,8 +251,9 @@ sub splash {
             }
         );
 
-        # Draws the Circle with GFB in it
-        $self->set_color({ 'red' => 64, 'green' => 0, 'blue' => 0 });
+        ### Draws the Circle with GFB in it ###
+        # The dark shadow circle
+        $self->set_color({ 'red' => 32, 'green' => 0, 'blue' => 0 });
         $self->circle(
             {
                 'x'      => (207 * $hf) + $X,
@@ -258,7 +263,7 @@ sub splash {
             }
         );
 
-        $self->set_color({ 'red' => 255, 'green' => 255, 'blue' => 0 });
+        # The "coin"
         $self->circle(
             {
                 'x'        => (200 * $hf) + $X,
@@ -267,16 +272,11 @@ sub splash {
                 'filled'   => TRUE,
                 'gradient' => {
                     'direction' => 'horizontal',
-                    'start'     => {
-                        'red'   => 255,
-                        'green' => 0,
-                        'blue'  => 0
+                    'colors'     => {
+                        'red'   => [255, 64, 255],
+                        'green' => [255, 64, 255],
+                        'blue'  => [255, 64, 255],
                     },
-                    'end' => {
-                        'red'   => 255,
-                        'green' => 255,
-                        'blue'  => 0
-                    }
                 }
             }
         );
